@@ -1,16 +1,16 @@
 # -*- coding: utf-8 -*-
 
-import asyncio
 import logging
 import math
 import platform
 import time
 import urllib
 import uuid as _uuid
-from datetime import datetime
+from datetime import datetime, timezone
 
 import aiohttp
-import requests
+
+from ._exceptions import InvalidTokenException
 
 APP_NAME = "DzienniczekPlus 2.0"
 APP_VERSION = "1.4.2"
@@ -26,21 +26,17 @@ log.addHandler(handler)
 TIME_FORMAT_H_M = "%H:%M"
 
 
-class VulcanAPIException(Exception):
-    pass
-
-
 def default_device_model():
-    return "Vulcan API (Python {})".format(platform.python_version())
+    return f"Vulcan API (Python {platform.python_version()})"
 
 
 async def get_base_url(token):
-    code = token[0:3]
+    code = token[:3]
     components = await get_components()
     try:
         return components[code]
-    except KeyError:
-        raise VulcanAPIException("Invalid token!")
+    except KeyError as e:
+        raise InvalidTokenException() from e
 
 
 async def get_components():
@@ -55,44 +51,45 @@ async def get_components():
                 components = {a[0]: a[1] for a in components}
             else:
                 components = {}
-            components.update({"FK1": "http://api.fakelog.tk"})
+            components["FK1"] = "http://api.fakelog.tk"
             return components
 
 
-def get_firebase_token():
-    log.info("Getting Firebase token...")
-    aid = "4609707972546570896:3626695765779152704"
-    device = aid.split(":")[0]
-    app = "pl.edu.vulcan.hebe"
+async def get_firebase_token():
+    async with aiohttp.ClientSession() as session:
+        log.info("Getting Firebase token...")
+        aid = "4609707972546570896:3626695765779152704"
+        device = aid.split(":")[0]
+        app = "pl.edu.vulcan.hebe"
+        data = {
+            "sender": "987828170337",
+            "X-scope": "*",
+            "X-gmp_app_id": "1:987828170337:android:ac97431a0a4578c3",
+            "app": app,
+            "device": device,
+        }
 
-    data = {
-        "sender": "987828170337",
-        "X-scope": "*",
-        "X-gmp_app_id": "1:987828170337:android:ac97431a0a4578c3",
-        "app": app,
-        "device": device,
-    }
+        headers = {
+            "Authorization": f"AidLogin {aid}",
+            "User-Agent": "Android-GCM/1.5",
+            "app": app,
+        }
 
-    headers = {
-        "Authorization": "AidLogin {}".format(aid),
-        "User-Agent": "Android-GCM/1.5",
-        "app": app,
-    }
-
-    r = requests.post(
-        "https://android.clients.google.com/c2dm/register3", data=data, headers=headers
-    )
-    token = r.text.split("=")[1]
-
-    return token
+        async with session.post(
+            "https://android.clients.google.com/c2dm/register3",
+            data=data,
+            headers=headers,
+        ) as r:
+            r_txt = await r.text()
+            return r_txt.split("=")[1]
 
 
 def millis():
     return math.floor(time.time() * 1000)
 
 
-def now_datetime():  # UTC+0
-    return datetime.utcnow()
+def now_datetime():  # RFC 2822, UTC+0
+    return datetime.now(timezone.utc)
 
 
 def now_iso(dt=None):  # ISO 8601, local timezone
@@ -100,7 +97,7 @@ def now_iso(dt=None):  # ISO 8601, local timezone
 
 
 def now_gmt(dt=None):  # RFC 2822, UTC+0
-    return (dt or datetime.utcnow()).strftime("%a, %d %b %Y %H:%M:%S GMT")
+    return (dt or datetime.now(timezone.utc)).strftime("%a, %d %b %Y %H:%M:%S GMT")
 
 
 def uuid(seed=None):
